@@ -79,7 +79,9 @@ def add_localizer(event):
     localizer = get_localizer(request)
     defaultdomain = tsf('ppss_auth').domain
     def auto_translate(*args, **kwargs):
-        return localizer.translate(tsf(*args, **kwargs))
+        thisdomain = kwargs['domain'] if 'domain' in kwargs else defaultdomain
+        kwargs.pop('domain',None)
+        return localizer.translate(tsf(*args, **kwargs),domain=thisdomain)
     def auto_pluralize(src,num, *args,**kwargs):
         thisdomain = kwargs['domain'] if 'domain' in kwargs else defaultdomain
         return localizer.pluralize(tsf(src,*args, **kwargs),'',num,domain=thisdomain)
