@@ -38,9 +38,7 @@ class Conf():
     def conf2list(confval,default=None):
         try:
             if not is_nonstr_iter(confval):
-                #print(repr(confval))
                 confval = aslist(confval,flatten=False)
-            print(repr(confval))
             return confval
         except Exception as e:
             l.exception(u"Exception parsing value:{}".format(confval))
