@@ -29,13 +29,13 @@ def checkPassword(user,newpassword):
   for prevpass in prevpasslist[0:constants.Conf.passwordpreviousdifferent]:
     l.debug("\n{}\n vs \n{}".format(passworddig, prevpass.password))
     if passworddig == prevpass.password:
-      l.warn("password already used at {}".format(prevpass.insertdt))
-      return chkResult(False,"password already used at {}",prevpass.insertdt )
+      l.warn("password already used on {}".format(prevpass.insertdt))
+      return chkResult(False,"password already used on {}",prevpass.insertdt )
   for reexp in constants.Conf.passwordrelist:
     myre = re.compile(reexp)
     if myre.search(newpassword) is None:
       l.info("password {} don't match constaint:{}".format(newpassword,reexp))
-      return chkResult(False, "password {} don't match constaint:{}",newpassword,reexp )
+      return chkResult(False, "password for user '{}' don't match constaint:{}",user.username,reexp )
   return chkResult(True,"ok")
 
 
