@@ -288,9 +288,9 @@ class AuthController():
                 retdict['msg']=__(self.request,"Password check doesn't match the password.")
                 return retdict
             username = self.request.session.get(Conf.sessionuser).get("name")
-            user = PPSsuser.checkLogin(username,oldpassword,self.request.dbsession)     
+            user,valid = PPSsuser.checkLogin(username,oldpassword,self.request.dbsession)     
 
-            if user:
+            if valid:
                 res = checkPassword(user,newpassword)
                 l.info("checkPassword result for user {} = {}".format(user.username, res.getMsg(self.request) ))
                 if res:
